@@ -38,7 +38,7 @@ def _st(st):
 def create_root_node(text, parser_cls, base_url=None):
     """Create root node for text using given parser class.
     """
-    body = text.strip().encode('utf8') or b'<html/>'
+    body = text.strip().replace('\x00', '').encode('utf8') or b'<html/>'
     parser = parser_cls(recover=True, encoding='utf8')
     root = etree.fromstring(body, parser=parser, base_url=base_url)
     if root is None:
@@ -121,24 +121,34 @@ class SelectorList(list):
         else:
             return default
 
-    def extract(self):
+    def getall(self):
         """
-        Call the ``.extract()`` method for each element is this list and return
+        Call the ``.get()`` method for each element is this list and return
         their results flattened, as a list of unicode strings.
         """
-        return [x.extract() for x in self]
-    getall = extract
+        return [x.get() for x in self]
+    extract = getall
 
-    def extract_first(self, default=None):
+    def get(self, default=None):
         """
-        Return the result of ``.extract()`` for the first element in this list.
+        Return the result of ``.get()`` for the first element in this list.
         If the list is empty, return the default value.
         """
         for x in self:
-            return x.extract()
+            return x.get()
         else:
             return default
-    get = extract_first
+    extract_first = get
+
+    @property
+    def attrib(self):
+        """Return the attributes dictionary for the first element.
+        If the list is empty, return an empty dict.
+        """
+        for x in self:
+            return x.attrib
+        else:
+            return {}
 
 
 class Selector(object):
@@ -263,11 +273,11 @@ class Selector(object):
         will be compiled to a regular expression using ``re.compile(regex)``.
 
         By default, character entity references are replaced by their
-        corresponding character (except for ``&amp;`` and ``&lt;``.
+        corresponding character (except for ``&amp;`` and ``&lt;``).
         Passing ``replace_entities`` as ``False`` switches off these
         replacements.
         """
-        return extract_regex(regex, self.extract(), replace_entities=replace_entities)
+        return extract_regex(regex, self.get(), replace_entities=replace_entities)
 
     def re_first(self, regex, default=None, replace_entities=True):
         """
@@ -276,13 +286,13 @@ class Selector(object):
         the argument is not provided).
 
         By default, character entity references are replaced by their
-        corresponding character (except for ``&amp;`` and ``&lt;``.
+        corresponding character (except for ``&amp;`` and ``&lt;``).
         Passing ``replace_entities`` as ``False`` switches off these
         replacements.
         """
         return next(iflatten(self.re(regex, replace_entities=replace_entities)), default)
 
-    def extract(self):
+    def get(self):
         """
         Serialize and return the matched nodes in a single unicode string.
         Percent encoded content is unquoted.
@@ -299,7 +309,7 @@ class Selector(object):
                 return u'0'
             else:
                 return six.text_type(self.root)
-    get = extract
+    extract = get
 
     def getall(self):
         """
@@ -330,16 +340,22 @@ class Selector(object):
             # remove namespace declarations
             etree.cleanup_namespaces(self.root)
 
+    @property
+    def attrib(self):
+        """Return the attributes dictionary for underlying element.
+        """
+        return dict(self.root.attrib)
+
     def __bool__(self):
         """
         Return ``True`` if there is any real content selected or ``False``
         otherwise.  In other words, the boolean value of a :class:`Selector` is
         given by the contents it selects.
         """
-        return bool(self.extract())
+        return bool(self.get())
     __nonzero__ = __bool__
 
     def __str__(self):
-        data = repr(self.extract()[:40])
+        data = repr(self.get()[:40])
         return "<%s xpath=%r data=%s>" % (type(self).__name__, self._expr, data)
     __repr__ = __str__
